@@ -89,7 +89,7 @@ def format_type(msg):
     if test_type == TestType.Module:
         return "Module"
     elif test_type == TestType.Suite:
-        if text_subtype == TestSubType.Feature:
+        if test_subtype == TestSubType.Feature:
             return "Feature"
         else:
             return "Suite"
@@ -175,4 +175,4 @@ def transform():
                 line = formatter[0](line, last_test_id, *formatter[1:])
             else:
                 line = None
-        line = yield line
\ No newline at end of file
+        line = yield line
