@@ -1,4 +1,5 @@
-# Copyright 2019 Vitaliy Zakaznikov (TestFlows Test Framework http://testflows.com)
+# Copyright 2019 Katteli Inc.
+# TestFlows Test Framework (http://testflows.com)
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -17,7 +18,7 @@ import hashlib
 #: debug mode
 debug = False
 #: time resolution (decimal places)
-time_resolution = 3
+time_resolution = 6
 #: hash length in bytes
 hash_length = 8
 #: hash function
@@ -31,5 +32,7 @@ output_format = None
 #: log file
 write_logfile = None
 read_logfile = None
+#: database
+database = None
 #: show skipped tests
 show_skipped = False
